#
# spec file for package seafile-client
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           seafile-client
Version:        9.0.9
Release:        1.1
Summary:        Cloud storage client
License:        GPL-3.0-only
URL:            https://github.com/haiwen/seafile-client/
Source0:        https://github.com/haiwen/%{name}/archive/v%{version}.tar.gz
Source1:        seafile.appdata.xml
Patch0:         01-fix-no-return-in-nonvoid.patch
Patch2:         fix-cmake-name.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libsearpc-devel
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  seafile-devel = %{version}
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libevent_core)
BuildRequires:  pkgconfig(libevent_extra)
BuildRequires:  pkgconfig(libevent_openssl)
BuildRequires:  pkgconfig(libevent_pthreads)
BuildRequires:  pkgconfig(uuid)
Requires:       python3-pysearpc
Requires:       seafile = %{version}
BuildRequires:  cmake(Qt5Core) >= 5.15.1
BuildRequires:  cmake(Qt5DBus) >= 5.15.1
BuildRequires:  cmake(Qt5Designer) >= 5.15.1
BuildRequires:  cmake(Qt5Gui) >= 5.15.1
BuildRequires:  cmake(Qt5Help) >= 5.15.1
BuildRequires:  cmake(Qt5LinguistTools) >= 5.15.1
BuildRequires:  cmake(Qt5Network) >= 5.15.1
BuildRequires:  cmake(Qt5Test) >= 5.15.1
BuildRequires:  cmake(Qt5UiTools) >= 5.15.1
BuildRequires:  cmake(Qt5WebEngineCore) >= 5.15.1
BuildRequires:  cmake(Qt5WebEngineWidgets) >= 5.15.1
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(sqlite3)

%description
Seafile is an open source cloud storage system with features on privacy protection and teamwork. Collections of files are
called libraries, and each library can be synced separately. A library can also be encrypted with a user chosen password.
Seafile also allows users to create groups and easily sharing files into groups.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fPIE -pie"
export CXXFLAGS="%{optflags} -fPIE -pie"
%cmake \
    -DCMAKE_BUILD_TYPE=Release \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DBUILD_SHIBBOLETH_SUPPORT=ON ..
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}%{_datarootdir}/appdata/
install -m 644 %{SOURCE1} %{buildroot}%{_datadir}/appdata/seafile.appdata.xml

%files
%doc README.md
%license LICENSE
%{_bindir}/seafile-applet
%{_datadir}/applications/seafile.desktop
%{_datadir}/icons/hicolor/128x128
%{_datadir}/icons/hicolor/128x128/apps
%{_datadir}/icons/hicolor/128x128/apps/seafile.png
%{_datadir}/icons/hicolor/16x16
%{_datadir}/icons/hicolor/16x16/apps
%{_datadir}/icons/hicolor/16x16/apps/seafile.png
%{_datadir}/icons/hicolor/22x22
%{_datadir}/icons/hicolor/22x22/apps
%{_datadir}/icons/hicolor/22x22/apps/seafile.png
%{_datadir}/icons/hicolor/24x24
%{_datadir}/icons/hicolor/24x24/apps
%{_datadir}/icons/hicolor/24x24/apps/seafile.png
%{_datadir}/icons/hicolor/32x32
%{_datadir}/icons/hicolor/32x32/apps
%{_datadir}/icons/hicolor/32x32/apps/seafile.png
%{_datadir}/icons/hicolor/48x48
%{_datadir}/icons/hicolor/48x48/apps
%{_datadir}/icons/hicolor/48x48/apps/seafile.png
%{_datadir}/icons/hicolor/scalable
%{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/seafile.svg
%{_datadir}/pixmaps/seafile.png
%{_datadir}/appdata/seafile.appdata.xml

%changelog
* Mon Oct 21 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.0.9:
  * Retry list repos request when failed (#1564)
  * Support password hash (#1543)
  * Set default timeout for api requests (#1563)
  * Add SSO button to the login dialog (#1565)
  * Fix the migration error in data cache (#1559)
  * openUrl add return value (#1556)
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Do not BuildRequire libseafile0: requring seafile-devel is
  sufficient and this devel package is responsible to bring the
  required libraries.
* Mon Feb 26 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.0.4:
  * Add sync error SYNC_ERROR_ID_CHECKOUT_FILE by @feiniks in #1479
  * Add block missing sync error by @feiniks in #1480
  * Upgrade to Qt 6.5.2 by @rumtid in #1482
  * Update i18n by @rumtid in #1486
  * Fix compatible issues on Qt6 framework by @rumtid in #1487
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Mon Jul  3 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.0.3 (no changelog).
* Wed Apr 12 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.0.1 (no changelog).
* Tue Jan  3 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.10 (no changelog).
* Mon Nov  7 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.9 (no changelog).
* Wed Jul 13 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.8 (no changelog)
- Rebase 01-fix-no-return-in-nonvoid.patch
* Mon May  9 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.7 (no changelog)
- Rebase 01-fix-no-return-in-nonvoid.patch
- Rebase fix-cmake-name.patch
* Thu Feb 24 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.6 (no changelog)
- Remove seafile-client_fix-compilation-glib2_68.patch
- Rebase fix-cmake-name.patch
- New minimum QT requirement is 5.15.1
* Fri Dec 10 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.5. No changelog.
* Tue Sep 14 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.4. No changelog.
* Sun Jun 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unused QtWebKit dependency.
- Use cmake() style BuildRequires
- Update to 8.0.3:
  * Update i18n
* Wed May 26 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to v8.0.2:
  * Fix bug for updating server address
  * [Mac, Linux] Pop-up notification when uploading files whose names
    are invalid on Windows
  * [Cli] Add --json option for listing libraries
  * Don't stop syncing a library when local folder is unavailable,
    if option is set
  * Use SOCKS5 proxy to resolve domain names
- Removed fix_qpainterpath.patch
- Rebase seafile-client_fix-compilation-glib2_68.patch
* Wed Apr 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Add seafile-client_fix-compilation-glib2_68.patch
* Mon Oct 12 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 7.0.10 (no changelog)
- Add fix-cmake-name.patch
* Fri Jul 31 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 7.0.9:
  * Avoid downloading existing blocks during sync download
  * Fix crash when cancel syncing before a library is synced
  * Fix incorrect error message in some error situations
* Mon Jun  8 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 7.0.8 (no changelog)
- Add fix_qpainterpath.patch
* Fri Apr 10 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.7 (no changelog)
* Thu Mar 12 2020 Paolo Stivanin <info@paolostivanin.com>
- Fix spec file
* Mon Feb 17 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.6
* Tue Jan 14 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.5
* Thu Nov 21 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.4
* Fri Nov 15 2019 Paolo Stivanin <info@paolostivanin.com>
- use spec-cleaner
- use fpie
* Tue Nov 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Add missing required deps
* Tue Nov 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Fix spec file
* Tue Nov 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Use new seafile package instead of libseafile0
* Tue Nov 12 2019 Paolo Stivanin <info@paolostivanin.com>
- update to v7.0.3
* Mon Aug 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.2
* Wed Jun 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.1
* Fri May 31 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.0
* Fri Jan 18 2019 Paolo Stivanin <pstivanin@suse.com>
- Update to v6.2.11
* Thu Dec 13 2018 Paolo Stivanin <pstivanin@suse.com>
- Update to v6.2.9
* Sat Sep 15 2018 Paolo Stivanin <info@paolostivanin.com>
- Update to v6.2.5
* Sat Sep  8 2018 Paolo Stivanin <info@paolostivanin.com>
- Remove unneeded build dep
* Sat Sep  8 2018 Paolo Stivanin <info@paolostivanin.com>
- Add shibboleth support
* Thu Sep  6 2018 flyos@mailoo.org
- Rebuild in Cloud:Seafile on new bases
* Wed Aug  8 2018 info@paolostivanin.com
- removed ccnet dep (starting from v6.2.0 is no longer required)
* Sat Aug  4 2018 christoph@stop.pe
- Updated to version 6.2.4
* Tue May 22 2018 christoph@stop.pe
- Updated to version 6.1.8
* Wed Mar 28 2018 christoph@stop.pe
- Fixed build error on CentOS 7
* Sun Dec 31 2017 christoph@stop.pe
- Updated to version 6.1.4
* Fri Dec  8 2017 christoph@stop.pe
- Added patch from https://github.com/haiwen/seafile-client/pull/940/files to fix openssl 1.1 compatibility
* Thu Dec  7 2017 christoph@stop.pe
- Updated to version 6.1.3
* Mon Jul  3 2017 christoph@stop.pe
- Updated to version 6.0.7
* Sat Feb 25 2017 christoph@stop.pe
- Added missing patch file
* Sat Feb 25 2017 christoph@stop.pe
- Fixed some build errors
* Sat Feb 25 2017 christoph@stop.pe
- Updated to version 6.0.4
* Mon Sep 26 2016 christoph@stop.pe
- Initial packaging
